Module surface_nets

Module surface_nets 

GPU-accelerated Surface Nets isosurface extraction.

Surface Nets is an algorithm for extracting isosurfaces from volumetric data (like signed distance fields). It produces higher quality meshes than Marching Cubes with simpler implementation.

Structs

GpuSurfaceNetsParams
Parameters for GPU Surface Nets extraction.
GpuSurfaceNetsResult
Result of GPU Surface Nets extraction.
SurfaceNetsPipeline
Pipeline for GPU Surface Nets extraction.

Functions

extract_isosurface_gpu
Extract isosurface from SDF values on GPU.
try_extract_isosurface_gpu
Try to extract isosurface on GPU, returning None if unavailable.